from prefect import task


@task
def hello_prefect_collection() -> str:
    """
    Sample task that says hello!

    Returns:
        A greeting for your collection
    """
    return "Hello, prefect-collection!"


@task
def goodbye_prefect_collection() -> str:
    """
    Sample task that says goodbye!

    Returns:
        A farewell for your collection
    """
    return "Goodbye, prefect-collection!"


@task
def really_swell_task() -> str:
    """
    A really swell task
    """
    return "This is a really swell task!"
